@@ -21,13 +21,16 @@ OK = 'OK'
 OPEN = 'Open'
 PREFERENCES = 'Preferences'
 PREVIOUS = 'Prev'
+PROCESS = 'Process'
 QUIT = 'Quit'
 REFRESH = 'Refresh'
 REPORT = 'Report'
 RENAME = 'Rename'
+RUN = 'Run'
 SAVE = 'Save'
 SAVE_PDF = 'Save as PDF'
 SEND = 'Send'
+START = 'Start'
 UPDATE = 'Update'
 UPGRADE = 'Upgrade'
 USE = 'Use'
